#include <windows.h>
#include "resource.h"

#pragma resource "WineBug.res"

HBITMAP hBitmap1;
HBITMAP hBitmap2;

void WineBug_OnPaint(HWND hwnd)
{
  PAINTSTRUCT ps;
  HDC hdc = BeginPaint(hwnd,&ps);

  HDC hdcMem = CreateCompatibleDC(NULL);

  // Bitmap 1
  HBITMAP hBitmapOld = (HBITMAP) SelectObject(hdcMem, hBitmap1);

  // This should NOT affect how the bitmaps are displayed
  SetBkColor(hdc, RGB(255, 0, 0));
  SetTextColor(hdc, RGB(0, 255, 0));

  // Copy bitmap 1 to the screen
  BITMAP bitmap;
  GetObject(hBitmap1, sizeof(bitmap), &bitmap);  
  BitBlt(hdc, 0, 0, bitmap.bmWidth, bitmap.bmHeight, hdcMem, 0, 0, SRCCOPY);


  // Bitmap 2
  SelectObject(hdcMem, hBitmap2);

  // This should NOT affect how the bitmaps are displayed
  SetBkColor(hdc, RGB(255, 0, 0));
  SetTextColor(hdc, RGB(0, 255, 0));

  //  Copy bitmap 2 to the screen
  GetObject(hBitmap2, sizeof(bitmap), &bitmap);  
  BitBlt(hdc, 100, 0, bitmap.bmWidth, bitmap.bmHeight, hdcMem, 0, 0, SRCCOPY);

  // Clean up
  SelectObject(hdcMem, hBitmapOld);
  DeleteDC(hdcMem);
  EndPaint(hwnd, &ps);
}  


void WineBug_OnCreate()
{
  // Load the Bitmaps
  HINSTANCE hInstance = GetModuleHandle(NULL);

  hBitmap1 = LoadBitmap(hInstance, MAKEINTRESOURCE(IDB_BITMAP1));
  hBitmap2 = LoadBitmap(hInstance, MAKEINTRESOURCE(IDB_BITMAP2));
}

void WineBug_OnDestroy()
{
  // Delete the bitmaps
  DeleteObject(hBitmap1);
  DeleteObject(hBitmap2);
  
  PostQuitMessage(0);
}


LRESULT CALLBACK WineBug_WindowProc(
  HWND hwnd,
  UINT uMsg,
  WPARAM wParam,
  LPARAM lParam)
{
  switch(uMsg)
  {
    case WM_CREATE:
      WineBug_OnCreate();
      return 0;

    case WM_DESTROY:
      WineBug_OnDestroy();
      return 0;

    case WM_PAINT:
      WineBug_OnPaint(hwnd);
      return 0;
  }
     
  return DefWindowProc(hwnd,uMsg,wParam,lParam);
}  


void WineBug_RegisterClass(
  HINSTANCE hInstance)
{
  WNDCLASS wc = {
    0,
    WineBug_WindowProc,
    0,0,
    hInstance,
    LoadIcon(NULL,IDI_APPLICATION),
    LoadCursor(NULL,IDC_ARROW),
    (HBRUSH)(COLOR_WINDOW+1),
    NULL,
    "WineBug"
  };
  RegisterClass(&wc);
}


int WINAPI WinMain(
  HINSTANCE hInstance,
  HINSTANCE hInstPrev,
  LPSTR lpszCmdLine,
  int nCmdShow)
{
  WineBug_RegisterClass(hInstance);
  
  HWND hwnd = CreateWindowEx(
    0L,
    "WineBug", "WINE Bug",
    WS_OVERLAPPEDWINDOW,
    CW_USEDEFAULT,CW_USEDEFAULT,250,150,
    HWND_DESKTOP,NULL,hInstance,NULL);
    
  ShowWindow(hwnd,nCmdShow);
  UpdateWindow(hwnd);
  
  MSG msg;
  while(GetMessage(&msg,0,0,0))
  {
    TranslateMessage(&msg);
    DispatchMessage(&msg);
  }
  return msg.wParam;
}
